unit URLLabel;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type

	TURLLabel = class(TLabel)
	private
		FURL: string;
  	FHiliteColor: TColor;
  	procedure SetURL(const Value: string);
  	procedure SetHiliteColor(const Value: TColor);
	private
    mouse_down: Boolean;
    orig_color: TColor;
	protected
    procedure Click; override;
    procedure MouseDown(Button: TMouseButton; Shift: TShiftState;
      X, Y: Integer); override;
	procedure MouseMove(Shift: TShiftState; X, Y: Integer); override;
    procedure MouseUp(Button: TMouseButton; Shift: TShiftState;
      X, Y: Integer); override;
	public
		constructor Create(AOwner: TComponent); override;
	published
    property URL: string read FURL write SetURL;
    property HiliteColor: TColor read FHiliteColor write SetHiliteColor stored True default clRed;
    property Cursor default crHandPoint;
	end;

procedure Register;

implementation

uses ShellAPI;

procedure Register;
begin
  RegisterComponents('Samples', [TURLLabel]);
end;

{ TURLLabel }

procedure TURLLabel.Click;
var
	h: HWnd;
begin
	h := 0;
	if Parent <> nil then
  	h := Parent.Handle;

	ShellExecute (h, 'open', PChar (FURL), nil, nil, SW_SHOWNORMAL);

	inherited;
end;

constructor TURLLabel.Create(AOwner: TComponent);
begin
  inherited;
  FHiliteColor := clRed;
  Font.Color := clBlue;
  Cursor := crHandPoint;
  Font.Style := Font.Style + [fsUnderline];
end;

procedure TURLLabel.MouseDown(Button: TMouseButton; Shift: TShiftState; X,
  Y: Integer);
begin
	inherited;
  orig_color := Font.Color;
	Font.Color := FHiliteColor;
	mouse_down := True;
end;

procedure TURLLabel.MouseMove(Shift: TShiftState; X, Y: Integer);
var
	p: TPoint;
begin
	inherited;
	if mouse_down then begin
		p.x := X;
		p.y := Y;
		if PtInRect (ClientRect, p) then
    	Font.Color := FHiliteColor
	  else
			Font.Color := orig_color;
  end;
end;

procedure TURLLabel.MouseUp(Button: TMouseButton; Shift: TShiftState; X,
  Y: Integer);
begin
	inherited;
	mouse_down := False;
  Font.Color := orig_color;
end;

procedure TURLLabel.SetHiliteColor(const Value: TColor);
begin
  FHiliteColor := Value;
end;

procedure TURLLabel.SetURL(const Value: string);
begin
  FURL := Value;
end;

end.
